package inventorymanage

import (
	"errors"
	"github.com/gin-gonic/gin"
	"go-admin/app/admin/models"
	"go-admin/tools/app"
	"net/http"
)

// 库存调拨相关代码

// InventoryAllotAdd 新增
// @Summary 新增
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotAddReq true "新增模型"
// @Success 200 {object} models.ErpInventoryAllotOrder
// @Router /api/v1/inventory/allot/add [post]
func InventoryAllotAdd(c *gin.Context) {
	req := &models.ErpStockListReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotEdit 编辑
// @Summary 编辑
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotEditReq true "编辑模型"
// @Success 200 {object} models.ErpInventoryAllotOrder
// @Router /api/v1/inventory/allot/edit [post]
func InventoryAllotEdit(c *gin.Context) {
	req := &models.ErpStockListReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotAudit 审核
// @Summary 审核
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotAuditReq true "审核模型"
// @Success 200 {object} app.Response
// @Router /api/v1/inventory/allot/audit [post]
func InventoryAllotAudit(c *gin.Context) {
	req := &models.ErpStockListReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotDelete 删除
// @Summary 删除
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotDeleteReq true "删除模型"
// @Success 200 {object} app.Response
// @Router /api/v1/inventory/allot/delete [post]
func InventoryAllotDelete(c *gin.Context) {
	req := &models.InventoryAllotDeleteReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotList 库存调拨列表
// @Summary 库存调拨列表
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotListReq true "库存调拨列表模型"
// @Success 200 {object} models.InventoryAllotListResp
// @Router /api/v1/inventory/allot/list [post]
func InventoryAllotList(c *gin.Context) {
	req := &models.InventoryAllotListReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotDetail 库存调拨详情
// @Summary 库存调拨详情
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotDetailReq true "库存调拨详情模型"
// @Success 200 {object} models.ErpInventoryAllotOrder
// @Router /api/v1/inventory/allot/detail [post]
func InventoryAllotDetail(c *gin.Context) {
	req := &models.InventoryAllotDetailReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotDeliver 调拨发货
// @Summary 调拨发货
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotDeliverReq true "调拨发货模型"
// @Success 200 {object} app.Response
// @Router /api/v1/inventory/allot/deliver [post]
func InventoryAllotDeliver(c *gin.Context) {
	req := &models.InventoryAllotDeliverReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}

// InventoryAllotReceive 调拨收货
// @Summary 调拨收货
// @Tags 库存调拨，V1.4.0
// @Produce json
// @Accept json
// @Param request body models.InventoryAllotReceiveReq true "调拨收货模型"
// @Success 200 {object} app.Response
// @Router /api/v1/inventory/allot/receive [post]
func InventoryAllotReceive(c *gin.Context) {
	req := &models.InventoryAllotReceiveReq{}
	if err := c.ShouldBindJSON(&req); err != nil {
		//logger.Error(err)
		app.Error(c, http.StatusBadRequest, errors.New("para err"), "参数错误")
		return
	}

	app.OK(c, "", "OK")
	return
}
