package models

// ErpDecisionReportReq 进销存报表入参
type ErpDecisionReportReq struct {
	StoreId       []uint32 `json:"store_id"`       // 门店id
	CommodityName []string `json:"commodity_name"` // 商品名称
	CategoryID    []uint32 `json:"category_id"`    // 商品分类id
	StartTime     string   `json:"start_time"`     // 开始时间
	EndTime       string   `json:"end_time"`       // 结束时间
	IsExport      uint32   `json:"is_export"`      // 1-导出
	PageIndex     int      `json:"pageIndex"`      // 页码
	PageSize      int      `json:"pageSize"`       // 页面条数
}

// ErpDecisionReportResp 进销存报表出参
type ErpDecisionReportResp struct {
	Total     int `json:"total"`     // 总条数/记录数
	PageIndex int `json:"pageIndex"` // 页码
	PageSize  int `json:"pageSize"`  // 页面条数
	DecisionSumData
	ExportUrl string               `json:"export_url"` // 导出excel路径
	List      []DecisionReportData `json:"list"`       //
}

// DecisionSumData 进销存汇总数据
type DecisionSumData struct {
	TotalBeginStock     uint32  `json:"total_begin_stock"`     // 期初库存
	TotalBeginAmount    float64 `json:"total_begin_amount"`    // 期初金额
	TotalPurchaseStock  uint32  `json:"total_purchase_stock"`  // 采购进货
	TotalPurchaseReturn uint32  `json:"total_purchase_return"` // 采购退货
	TotalOrderSale      uint32  `json:"total_order_sale"`      // 零售销售
	TotalOrderReject    uint32  `json:"total_order_reject"`    // 零售退货
	TotalAllotIn        uint32  `json:"total_allot_in"`        // 调拨入库
	TotalAllotWaitIn    uint32  `json:"total_allot_wait_in"`   // 在途库存（入库）
	TotalAllotOut       uint32  `json:"total_allot_out"`       // 调拨出库
	TotalAllotWaitOut   uint32  `json:"total_allot_wait_out"`  // 在途库存（出库）
	TotalProductIn      uint32  `json:"total_product_in"`      // 产品入库
	TotalSystemOut      uint32  `json:"total_system_out"`      // 系统出库
	TotalCheckIn        uint32  `json:"total_check_in"`        // 盘点入库
	TotalCheckOut       uint32  `json:"total_check_out"`       // 盘点出库
	TotalEndStock       uint32  `json:"total_end_stock"`       // 期末数量
	TotalEndAmount      float64 `json:"total_end_amount"`      // 期末金额
}

// DecisionReportData 进销存报表数据
type DecisionReportData struct {
	CommodityId    uint32  `json:"commodity_id"`    // 商品id
	CommodityName  string  `json:"commodity_name"`  // 商品名称
	CategoryID     uint32  `json:"category_id"`     // 商品分类id
	CategoryName   string  `json:"category_name"`   // 商品分类名称
	BeginStock     uint32  `json:"begin_stock"`     // 期初库存
	BeginAmount    float64 `json:"begin_amount"`    // 期初金额
	PurchaseStock  uint32  `json:"purchase_stock"`  // 采购进货
	PurchaseReturn uint32  `json:"purchase_return"` // 采购退货
	OrderSale      uint32  `json:"order_sale"`      // 零售销售
	OrderReject    uint32  `json:"order_reject"`    // 零售退货
	AllotIn        uint32  `json:"allot_in"`        // 调拨入库
	AllotWaitIn    uint32  `json:"allot_wait_in"`   // 在途库存（入库）
	AllotOut       uint32  `json:"allot_out"`       // 调拨出库
	AllotWaitOut   uint32  `json:"allot_wait_out"`  // 在途库存（出库）
	ProductIn      uint32  `json:"product_in"`      // 产品入库
	SystemOut      uint32  `json:"system_out"`      // 系统出库
	CheckIn        uint32  `json:"check_in"`        // 盘点入库
	CheckOut       uint32  `json:"check_out"`       // 盘点出库
	EndStock       uint32  `json:"end_stock"`       // 期末数量
	EndAmount      float64 `json:"end_amount"`      // 期末金额
}
