package models

import "time"

// ErpInventoryAllotOrder 库存调拨订单表
type ErpInventoryAllotOrder struct {
	Model
	SerialNumber     string                       `json:"serial_number" gorm:"index"`    // 单据编号
	DeliverStoreId   uint32                       `json:"deliver_store_id" gorm:"index"` // 调出门店id
	DeliverStoreName string                       `json:"deliver_store_name"`            // 调出门店名称
	ReceiveStoreId   uint32                       `json:"receive_store_id" gorm:"index"` // 调入门店id
	ReceiveStoreName string                       `json:"receive_store_name"`            // 调入门店名称
	HandlerId        uint32                       `json:"handler_id" gorm:"index"`       // 经手人id
	HandlerName      string                       `json:"handler_name"`                  // 经手人名称
	MakerTime        *time.Time                   `json:"maker_time"`                    // 制单时间
	MakerId          uint32                       `json:"maker_id" gorm:"index"`         // 制单人id
	MakerName        string                       `json:"maker_name"`                    // 制单人名称
	AuditTime        *time.Time                   `json:"audit_time"`                    // 审核时间
	AuditorId        uint32                       `json:"auditor_id" gorm:"index"`       // 审核人id
	AuditorName      string                       `json:"auditor_name"`                  // 审核人名称
	DeliverTime      *time.Time                   `json:"deliver_time"`                  // 发货时间
	ReceiveTime      *time.Time                   `json:"receive_time"`                  // 收货时间/调入时间
	LogisticsNumber  string                       `json:"logistics_number"`              // 物流单号
	State            uint32                       `json:"state"`                         // 1-待审核 2-待发货 3-待收货 4-已完成
	TotalCount       uint32                       `json:"total_count"`                   // 商品总数量
	Remark           string                       `json:"remark"`                        // 备注
	Commodities      []ErpInventoryAllotCommodity `json:"commodities" gorm:"-"`          // 库存调拨商品信息
}

// ErpInventoryAllotCommodity 库存调拨商品信息表
type ErpInventoryAllotCommodity struct {
	Model
	AllotOrderId  uint32 `json:"allot_order_id" gorm:"index"` // 库存调拨订单表id
	CommodityId   uint32 `json:"commodity_id" gorm:"index"`   // 商品id
	CommodityName string `json:"commodity_name"`              // 商品名称
	IMEIType      uint32 `json:"imei_type"`                   // 1-无串码 2-串码
	IMEI          string `json:"imei"`                        // 商品串码
	Count         uint32 `json:"count"`                       // 数量
	Remark        string `json:"remark"`                      // 备注
}

// InventoryAllotAddReq 新增库存调拨入参
type InventoryAllotAddReq struct {
	DeliverStoreId   uint32                       `json:"deliver_store_id" binding:"required"`   // 调出门店id
	DeliverStoreName string                       `json:"deliver_store_name" binding:"required"` // 调出门店名称
	ReceiveStoreId   uint32                       `json:"receive_store_id" binding:"required"`   // 调入门店id
	ReceiveStoreName string                       `json:"receive_store_name" binding:"required"` // 调入门店名称
	HandlerId        uint32                       `json:"handler_id" binding:"required"`         // 经手人id
	HandlerName      string                       `json:"handler_name" binding:"required"`       // 经手人名称
	Commodities      []ErpInventoryAllotCommodity `json:"commodities"  binding:"required"`       // 库存调拨商品信息
}

// InventoryAllotEditReq 编辑库存调拨入参
type InventoryAllotEditReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
	InventoryAllotAddReq
}

// InventoryAllotAuditReq 审核入参
type InventoryAllotAuditReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
	State        int    `json:"state"  binding:"required"`        // 审核操作: 1-审核 2-取消审核
}

// InventoryAllotDeleteReq 删除入参
type InventoryAllotDeleteReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
}

// InventoryAllotListReq 查询库存调拨列表入参
type InventoryAllotListReq struct {
	SerialNumber   string `json:"serial_number"`    // 单据编号
	DeliverStoreId uint32 `json:"deliver_store_id"` // 调出门店id
	ReceiveStoreId uint32 `json:"receive_store_id"` // 调入门店id
	HandlerId      uint32 `json:"handler_id"`       // 经手人id
	State          int    `json:"state"`            // 1-待审核 2-待发货 3-待收货 4-已完成
	AuditTimeStart string `json:"audit_time_start"` // 审核开始时间
	AuditTimeEnd   string `json:"audit_time_end"`   // 审核结束时间
	PageIndex      int    `json:"pageIndex"`        // 页码
	PageSize       int    `json:"pageSize"`         // 页面条数
}

// InventoryAllotListResp 查询库存调拨列表出参
type InventoryAllotListResp struct {
	List      []ErpInventoryAllotOrder `json:"list"`
	Total     int                      `json:"total"`     // 总条数
	PageIndex int                      `json:"pageIndex"` // 页码
	PageSize  int                      `json:"pageSize"`  // 页面条数
}

// InventoryAllotDetailReq  查询库存调拨详情入参
type InventoryAllotDetailReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
}

// InventoryAllotDeliverReq 调拨发货入参
type InventoryAllotDeliverReq struct {
	SerialNumber    string `json:"serial_number" binding:"required"` // 单据编号
	LogisticsNumber string `json:"logistics_number"`                 // 物流单号
	Remark          string `json:"remark"`                           // 备注
}

// InventoryAllotReceiveReq 调拨收货入参
type InventoryAllotReceiveReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
}
