package models

import "time"

// ErpInventoryChangeOrder 库存变动订单表
type ErpInventoryChangeOrder struct {
	Model
	SerialNumber string                        `json:"serial_number" gorm:"index"` // 单据编号
	ChangeType   string                        `json:"change_type"`                // 类型:add-增加；reduce-减少
	StoreId      uint32                        `json:"store_id" gorm:"index"`      // 门店id
	StoreName    string                        `json:"store_name"`                 // 门店名称
	HandlerId    uint32                        `json:"handler_id" gorm:"index"`    // 经手人id
	HandlerName  string                        `json:"handler_name"`               // 经手人名称
	MakerTime    *time.Time                    `json:"maker_time"`                 // 制单时间
	MakerId      uint32                        `json:"maker_id" gorm:"index"`      // 制单人id
	MakerName    string                        `json:"maker_name"`                 // 制单人名称
	AuditTime    *time.Time                    `json:"audit_time"`                 // 审核时间
	AuditorId    uint32                        `json:"auditor_id" gorm:"index"`    // 审核人id
	AuditorName  string                        `json:"auditor_name"`               // 审核人名称
	State        uint32                        `json:"state"`                      // 1-待审核 2-已完成
	TotalCount   uint32                        `json:"total_count"`                // 总数量
	TotalAmount  float64                       `json:"total_amount"`               // 总金额
	Commodities  []ErpInventoryChangeCommodity `json:"commodities" gorm:"-"`       // 库存变动商品信息
}

// ErpInventoryChangeCommodity 库存变动商品信息表
type ErpInventoryChangeCommodity struct {
	Model
	ChangeOrderId uint32  `json:"change_order_id" gorm:"index"` // 库存变动订单表id
	CommodityId   uint32  `json:"commodity_id" gorm:"index"`    // 商品id
	CommodityName string  `json:"commodity_name"`               // 商品名称
	SupplierId    uint32  `json:"supplier_id" gorm:"index"`     // 供应商id
	SupplierName  string  `json:"supplier_name"`                // 供应商名称
	IMEIType      uint32  `json:"imei_type"`                    // 1-无串码 2-串码
	IMEI          string  `json:"imei"`                         // 商品串码
	Count         uint32  `json:"count"`                        // 计划数量
	Price         float64 `json:"price"`                        // 采购单价
	EmployeePrice float64 `json:"employee_price"`               // 员工成本价
	Amount        float64 `json:"amount"`                       // 金额
	Remark        string  `json:"remark"`                       // 备注
}

// InventoryChangeAddReq 新增库存变动入参
type InventoryChangeAddReq struct {
	StoreId     uint32                        `json:"store_id" binding:"required"`     // 门店id
	StoreName   string                        `json:"store_name" binding:"required"`   // 门店名称
	HandlerId   uint32                        `json:"handler_id" binding:"required"`   // 经手人id
	HandlerName string                        `json:"handler_name" binding:"required"` // 经手人名称
	Commodities []ErpInventoryChangeCommodity `json:"commodities"  binding:"required"` // 库存变动商品信息
}

// InventoryChangeEditReq 编辑库存变动入参
type InventoryChangeEditReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
	InventoryChangeAddReq
}

// InventoryChangeAuditReq 审核入参
type InventoryChangeAuditReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
	State        int    `json:"state"  binding:"required"`        // 审核操作: 1-审核 2-取消审核
}

// InventoryChangeDeleteReq 删除入参
type InventoryChangeDeleteReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
}

// InventoryChangeListReq 查询库存变动列表入参
type InventoryChangeListReq struct {
	SerialNumber   string `json:"serial_number"`    // 单据编号
	ChangeType     string `json:"change_type"`      // 类型:add-增加；reduce-减少
	StoreId        uint32 `json:"store_id"`         // 门店id
	HandlerId      uint32 `json:"handler_id"`       // 经手人id
	State          int    `json:"state"`            // 1-待审核 2-已完成
	AuditTimeStart string `json:"audit_time_start"` // 审核开始时间
	AuditTimeEnd   string `json:"audit_time_end"`   // 审核结束时间
	PageIndex      int    `json:"pageIndex"`        // 页码
	PageSize       int    `json:"pageSize"`         // 页面条数
}

// InventoryChangeListResp 查询库存变动列表出参
type InventoryChangeListResp struct {
	List      []ErpInventoryChangeOrder `json:"list"`
	Total     int                       `json:"total"`     // 总条数
	PageIndex int                       `json:"pageIndex"` // 页码
	PageSize  int                       `json:"pageSize"`  // 页面条数
}

// InventoryChangeDetailReq  查询库存变动详情入参
type InventoryChangeDetailReq struct {
	SerialNumber string `json:"serial_number" binding:"required"` // 单据编号
}
