package models

import "time"

// InventoryReportByProductReq 产品库存汇总（按门店）入参
type InventoryReportByProductReq struct {
	StoreId               []uint32 `json:"store_id"`                // 门店id
	CommoditySerialNumber []string `json:"commodity_serial_number"` // 商品编号
	CommodityName         []string `json:"commodity_name"`          // 商品名称
	CategoryID            []uint32 `json:"category_id"`             // 商品分类id
	IsExport              uint32   `json:"is_export"`               // 1-导出
	PageIndex             int      `json:"pageIndex"`               // 页码
	PageSize              int      `json:"pageSize"`                // 页面条数
}

// InventoryReportByProductResp 产品库存汇总（按门店）出参
type InventoryReportByProductResp struct {
	Total                int                   `json:"total"`                  // 总条数/记录数
	PageIndex            int                   `json:"pageIndex"`              // 页码
	PageSize             int                   `json:"pageSize"`               // 页面条数
	TotalEffectiveCount  uint32                `json:"total_effective_count"`  // 有效库存数
	TotalTransferCount   uint32                `json:"total_transfer_count"`   // 调入中数量
	TotalCount           uint32                `json:"total_count"`            // 总数量
	TotalEffectiveAmount float64               `json:"total_effective_amount"` // 有效库存金额
	TotalTransferAmount  float64               `json:"total_transfer_amount"`  // 调入中金额
	ExportUrl            string                `json:"export_url"`             // 导出excel路径
	List                 []ReportByProductData `json:"list"`                   //
}

// ReportByProductData 产品库存汇总（按门店）数据
type ReportByProductData struct {
	StoreId               uint32  `json:"store_id"`                // 门店id
	StoreName             string  `json:"store_name"`              // 门店名称
	CommoditySerialNumber string  `json:"commodity_serial_number"` // 商品编号
	CommodityId           uint32  `json:"commodity_id"`            // 商品id
	CommodityName         string  `json:"commodity_name"`          // 商品名称
	CategoryID            uint32  `json:"category_id"`             // 商品分类id
	CategoryName          string  `json:"category_name"`           // 商品分类名称
	EffectiveCount        uint32  `json:"effective_count"`         // 有效库存数
	TransferCount         uint32  `json:"transfer_count"`          // 调入中数量
	Count                 uint32  `json:"count"`                   // 总数量
	EffectiveAmount       float64 `json:"effective_amount"`        // 有效库存金额
	TransferAmount        float64 `json:"transfer_amount"`         // 调入中金额
}

// InventoryReportByAllotReq 库存调拨入参
type InventoryReportByAllotReq struct {
	DeliverStoreId   []uint32 `json:"deliver_store_id"`   // 调出门店id
	ReceiveStoreId   []uint32 `json:"receive_store_id"`   // 调入门店id
	CommodityName    []string `json:"commodity_name"`     // 商品名称
	CategoryID       []uint32 `json:"category_id"`        // 商品分类id
	State            uint32   `json:"state"`              // 调拨状态：1-调拨中 2-已完成
	AuditTimeStart   string   `json:"audit_time_start"`   // 审核/发起开始时间
	AuditTimeEnd     string   `json:"audit_time_end"`     // 审核/发起结束时间
	ReceiveTimeStart string   `json:"receive_time_start"` // 调入开始时间
	ReceiveTimeEnd   string   `json:"receive_time_end"`   // 调入结束时间
	IsExport         uint32   `json:"is_export"`          // 1-导出
	PageIndex        int      `json:"pageIndex"`          // 页码
	PageSize         int      `json:"pageSize"`           // 页面条数
}

// InventoryReportByAllotResp 库存调拨出参
type InventoryReportByAllotResp struct {
	Total            int                 `json:"total"`              // 总条数/记录数
	PageIndex        int                 `json:"pageIndex"`          // 页码
	PageSize         int                 `json:"pageSize"`           // 页面条数
	TotalAllotCount  uint32              `json:"total_allot_count"`  // 调拨数量
	TotalAllotAmount float64             `json:"total_allot_amount"` // 调拨金额
	ExportUrl        string              `json:"export_url"`         // 导出excel路径
	List             []ReportByAllotData `json:"list"`               //
}

// ReportByAllotData 库存调拨数据
type ReportByAllotData struct {
	DeliverStoreId   uint32  `json:"deliver_store_id"`   // 调出门店id
	DeliverStoreName string  `json:"deliver_store_name"` // 调出门店名称
	ReceiveStoreId   uint32  `json:"receive_store_id"`   // 调入门店id
	ReceiveStoreName string  `json:"receive_store_name"` // 调入门店名称
	CommodityId      uint32  `json:"commodity_id"`       // 商品id
	CommodityName    string  `json:"commodity_name"`     // 商品名称
	CategoryID       uint32  `json:"category_id"`        // 商品分类id
	CategoryName     string  `json:"category_name"`      // 商品分类名称
	State            uint32  `json:"state"`              // 调拨状态：1-调拨中 2-已完成
	AllotCount       uint32  `json:"allot_count"`        // 调拨数量
	AllotAmount      float64 `json:"allot_amount"`       // 调拨金额
}

// InventoryReportAllotDetailReq 库存调拨明细入参
type InventoryReportAllotDetailReq struct {
	SerialNumber     string   `json:"serial_number"`      // 单据编号
	DeliverStoreId   uint32   `json:"deliver_store_id"`   // 调出门店id
	ReceiveStoreId   uint32   `json:"receive_store_id"`   // 调入门店id
	CommodityName    []string `json:"commodity_name"`     // 商品名称
	CategoryID       []uint32 `json:"category_id"`        // 商品分类id
	State            uint32   `json:"state"`              // 调拨状态：1-调拨中 2-已完成
	AuditTimeStart   string   `json:"audit_time_start"`   // 审核/发起开始时间
	AuditTimeEnd     string   `json:"audit_time_end"`     // 审核/发起结束时间
	ReceiveTimeStart string   `json:"receive_time_start"` // 调入开始时间
	ReceiveTimeEnd   string   `json:"receive_time_end"`   // 调入结束时间
	IsExport         uint32   `json:"is_export"`          // 1-导出
	PageIndex        int      `json:"pageIndex"`          // 页码
	PageSize         int      `json:"pageSize"`           // 页面条数
}

// InventoryReportAllotDetailResp 库存调拨明细出参
type InventoryReportAllotDetailResp struct {
	Total     int                     `json:"total"`      // 总条数/记录数
	PageIndex int                     `json:"pageIndex"`  // 页码
	PageSize  int                     `json:"pageSize"`   // 页面条数
	ExportUrl string                  `json:"export_url"` // 导出excel路径
	List      []ReportAllotDetailData `json:"list"`       //
}

// ReportAllotDetailData 库存调拨明细数据
type ReportAllotDetailData struct {
	SerialNumber     string     `json:"serial_number"`      // 单据编号
	DeliverStoreId   uint32     `json:"deliver_store_id"`   // 调出门店id
	DeliverStoreName string     `json:"deliver_store_name"` // 调出门店名称
	ReceiveStoreId   uint32     `json:"receive_store_id"`   // 调入门店id
	ReceiveStoreName string     `json:"receive_store_name"` // 调入门店名称
	MakerTime        *time.Time `json:"maker_time"`         // 制单时间/发起时间
	AuditTime        *time.Time `json:"audit_time"`         // 审核时间
	State            uint32     `json:"state"`              // 调拨状态：1-调拨中 2-已完成
	CommodityId      uint32     `json:"commodity_id"`       // 商品id
	CommodityName    string     `json:"commodity_name"`     // 商品名称
	CategoryID       uint32     `json:"category_id"`        // 商品分类id
	CategoryName     string     `json:"category_name"`      // 商品分类名称
	IMEIType         uint32     `json:"imei_type"`          // 1-无串码 2-串码
	IMEI             string     `json:"imei"`               // 商品串码
}

// InventoryReportByOtherReq 其他出入库汇总入参
type InventoryReportByOtherReq struct {
	StoreId       []uint32 `json:"store_id"`       // 门店id
	CommodityName []string `json:"commodity_name"` // 商品名称
	CategoryID    []uint32 `json:"category_id"`    // 商品分类id
	State         uint32   `json:"state"`          // 调拨状态：1-产品入库 2-盘点入库 3-系统出库 4-盘点出库
	StartTime     string   `json:"start_time"`     // 开始时间/入库时间
	EndTime       string   `json:"end_time"`       // 结束时间/出库时间
	IsExport      uint32   `json:"is_export"`      // 1-导出
	PageIndex     int      `json:"pageIndex"`      // 页码
	PageSize      int      `json:"pageSize"`       // 页面条数
}

// InventoryReportByOtherResp 其他出入库汇总出参
type InventoryReportByOtherResp struct {
	Total       int                 `json:"total"`        // 总条数/记录数
	PageIndex   int                 `json:"pageIndex"`    // 页码
	PageSize    int                 `json:"pageSize"`     // 页面条数
	TotalCount  int32               `json:"total_count"`  // 总数量
	TotalAmount float64             `json:"total_amount"` // 总金额
	ExportUrl   string              `json:"export_url"`   // 导出excel路径
	List        []ReportByOtherData `json:"list"`         //
}

// ReportByOtherData 其他出入库汇总数据
type ReportByOtherData struct {
	StoreId       uint32  `json:"store_id"`       // 门店id
	StoreName     string  `json:"store_name"`     // 门店名称
	CommodityId   uint32  `json:"commodity_id"`   // 商品id
	CommodityName string  `json:"commodity_name"` // 商品名称
	CategoryID    uint32  `json:"category_id"`    // 商品分类id
	CategoryName  string  `json:"category_name"`  // 商品分类名称
	State         uint32  `json:"state"`          // 调拨状态：1-产品入库 2-盘点入库 3-系统出库 4-盘点出库
	Count         int32   `json:"count"`          // 数量
	Amount        float64 `json:"amount"`         // 金额
}

// InventoryReportOtherDetailReq 其他出入库明细入参
type InventoryReportOtherDetailReq struct {
	SerialNumber  string   `json:"serial_number"`  // 单据编号
	StoreId       []uint32 `json:"store_id"`       // 门店id
	CommodityName []string `json:"commodity_name"` // 商品名称
	CategoryID    []uint32 `json:"category_id"`    // 商品分类id
	State         uint32   `json:"state"`          // 调拨状态：1-产品入库 2-盘点入库 3-系统出库 4-盘点出库
	StartTime     string   `json:"start_time"`     // 开始时间/入库时间
	EndTime       string   `json:"end_time"`       // 结束时间/出库时间
	IsExport      uint32   `json:"is_export"`      // 1-导出
	PageIndex     int      `json:"pageIndex"`      // 页码
	PageSize      int      `json:"pageSize"`       // 页面条数
}

// InventoryReportOtherDetailResp 其他出入库明细出参
type InventoryReportOtherDetailResp struct {
	Total              int                     `json:"total"`                // 总条数/记录数
	PageIndex          int                     `json:"pageIndex"`            // 页码
	PageSize           int                     `json:"pageSize"`             // 页面条数
	TotalPurchasePrice float64                 `json:"total_purchase_price"` // 总入库采购价
	TotalEmployeePrice float64                 `json:"total_employee_price"` // 总入库员工成本价
	ExportUrl          string                  `json:"export_url"`           // 导出excel路径
	List               []ReportOtherDetailData `json:"list"`                 //
}

// ReportOtherDetailData 其他出入库明细数据
type ReportOtherDetailData struct {
	CommodityId   uint32     `json:"commodity_id"`   // 商品id
	CommodityName string     `json:"commodity_name"` // 商品名称
	CategoryID    uint32     `json:"category_id"`    // 商品分类id
	CategoryName  string     `json:"category_name"`  // 商品分类名称
	IMEIType      uint32     `json:"imei_type"`      // 1-无串码 2-串码
	IMEI          string     `json:"imei"`           // 商品串码
	StoreId       uint32     `json:"store_id"`       // 门店id
	StoreName     string     `json:"store_name"`     // 门店名称
	SupplierId    uint32     `json:"supplier_id"`    // 供应商id
	SupplierName  string     `json:"supplier_name"`  // 供应商名称
	StockTime     *time.Time `json:"stock_time"`     // 出入库时间
	State         uint32     `json:"state"`          // 调拨状态：1-产品入库 2-盘点入库 3-系统出库 4-盘点出库
	SerialNumber  string     `json:"serial_number"`  // 单据编号
	PurchasePrice float64    `json:"purchase_price"` // 入库采购价
	EmployeePrice float64    `json:"employee_price"` // 入库员工成本价
}
